==> arnie-0.2.22.tgz: package/lib/index.test.js <==
'use strict';

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var t = require('tap');
var A = require('../src');
var arnie = A();

// const operators = require('../operators')
// const providers = require('../providers')
// const serverless = require('../serverless')

t.test('Arnie', function (t) {
  t.plan(4);

  // t.assert(serverless, 'should expose: const serverless = require(arnie/serverless)')
  // t.assert(operators.forEach, 'should expose: const {forEach} = require(arnie/operators)')
  // t.assert(operators.set, 'should expose: const {set} = require(arnie/operators)')
  // t.assert(operators.when, 'should expose: const {when} = require(arnie/operators)')
  // t.assert(operators.when, 'should expose: const {when} = require(arnie/operators)')
  // t.assert(providers.HttpResponseProvider, 'should expose: const {HttpResponseProvider} = require(arnie/providers)')
  // t.assert(providers.OutputProvider, 'should expose: const {OutputProvider} = require(arnie/providers)')
  // t.assert(providers.ServerlessRequestProvider, 'should expose: const {ServerlessRequestProvider} = require(arnie/providers)')

  var inititalData = { foo: 'bar' };
  var mutation = { foo: 'mutated' };
  var expectedOutput = {
    foo: mutation.foo,
    bar: 'foo'
  };
  var task = [function (_ref) {
    var input = _ref.input;

    t.deepEqual(input, inititalData, 'should execute first action with initital input');
    return _promise2.default.resolve(mutation);
  }, function (_ref2) {
    var input = _ref2.input;

    t.deepEqual(input, mutation, 'should execute subsequent action with mutated input');
    return { bar: expectedOutput.bar };
  }];

  arnie(task, inititalData).then(function (output) {
    t.deepEqual(output, expectedOutput, 'should run function tree and resolve with final payload');
  });

  var expectedError = new Error('error');
  arnie([function () {
    throw expectedError;
  }]).then(function () {
    return t.fail('should not resolve on error');
  }).catch(function (error) {
    t.equal(error, expectedError, 'should reject failed execution with error');
  });
});

==> arnie-0.3.1.tgz: package/lib/index.test.js <==
'use strict';

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var t = require('tap');
var A = require('../src');

var _require = require('../src'),
    sequence = _require.sequence,
    parallel = _require.parallel;

var arnie = A();

// const operators = require('../operators')
// const providers = require('../providers')
// const serverless = require('../serverless')

t.test('Arnie', function (t) {
  t.plan(5);

  // t.assert(serverless, 'should expose: const serverless = require(arnie/serverless)')
  // t.assert(operators.forEach, 'should expose: const {forEach} = require(arnie/operators)')
  // t.assert(operators.set, 'should expose: const {set} = require(arnie/operators)')
  // t.assert(operators.when, 'should expose: const {when} = require(arnie/operators)')
  // t.assert(operators.when, 'should expose: const {when} = require(arnie/operators)')
  // t.assert(providers.HttpResponseProvider, 'should expose: const {HttpResponseProvider} = require(arnie/providers)')
  // t.assert(providers.OutputProvider, 'should expose: const {OutputProvider} = require(arnie/providers)')
  // t.assert(providers.ServerlessRequestProvider, 'should expose: const {ServerlessRequestProvider} = require(arnie/providers)')

  var parallelCount = 0;
  var inititalData = { foo: 'bar' };
  var mutation = { foo: 'mutated' };
  var expectedOutput = {
    foo: mutation.foo,
    bar: 'foo'
  };

  var task = sequence([function (_ref) {
    var props = _ref.props;

    t.deepEqual(props, inititalData, 'should execute first action with initital props');
    return _promise2.default.resolve(mutation);
  }, function (_ref2) {
    var props = _ref2.props;

    t.deepEqual(props, mutation, 'should execute subsequent action with mutated props');
    return { bar: expectedOutput.bar };
  }, parallel([function (_ref3) {
    var props = _ref3.props;

    return new _promise2.default(function (resolve) {
      setTimeout(function () {
        parallelCount += 1;
        t.assert(parallelCount === 2, 'should allow parallel execution');
        resolve();
      }, 100);
    });
  }, function (_ref4) {
    var props = _ref4.props;

    return new _promise2.default(function (resolve) {
      setTimeout(function () {
        parallelCount += 1;
        resolve();
      }, 1);
    });
  }])]);

  arnie(task, inititalData).then(function (output) {
    t.deepEqual(output, expectedOutput, 'should run function tree and resolve with final payload');
  });

  var expectedError = new Error('error');
  arnie([function () {
    throw expectedError;
  }]).then(function () {
    return t.fail('should not resolve on error');
  }).catch(function (error) {
    t.equal(error, expectedError, 'should reject failed execution with error');
  });
});
